@@ -709,7 +709,7 @@ namespace tut {
 			"Transfer-Encoding: chunked\r\n\r\n");
 		string response = readAll(fd, 1024).first;
 		ensure(containsSubstring(response,
-			"HTTP/1.1 400 Bad Request\r\n"
+			"HTTP/1.0 400 Bad Request\r\n"
 			"Status: 400 Bad Request\r\n"
 			"Content-Type: text/html; charset=UTF-8\r\n"));
 		ensure(containsSubstring(response,
@@ -720,6 +720,56 @@ namespace tut {
 			"Bad request (request may not contain both Content-Length and Transfer-Encoding)"));
 	}
 
+	TEST_METHOD(16) {
+		set_test_name("Request Smuggling type: 1");
+
+		connectToServer();
+		sendRequest(
+			"POST / HTTP/1.1\r\n"
+			"Host: whatever\r\n"
+			"Transfer-Encoding: ,chunked\r\n"
+			"Content-Length: 5\r\n"
+			"\r\n"
+			"0\r\n"
+			"\r\n");
+		string response = readAll(fd, 1024).first;
+		ensure(containsSubstring(response,
+			"HTTP/1.0 400 Bad Request\r\n"
+			"Status: 400 Bad Request\r\n"
+			"Content-Type: text/html; charset=UTF-8\r\n"));
+		ensure(containsSubstring(response,
+			"Connection: close\r\n"
+			"Content-Length: 79\r\n"
+			"cache-control: no-cache, no-store, must-revalidate\r\n"
+			"\r\n"
+			"Bad request (request may not contain both Content-Length and Transfer-Encoding)"));
+	}
+
+	TEST_METHOD(17) {
+		set_test_name("Request Smuggling type: 2");
+
+		connectToServer();
+		sendRequest(
+			"POST / HTTP/1.1\r\n"
+			"Host: whatever\r\n"
+			"Transfer-\r\n"
+			"Encoding: chunked\r\n"
+			"Content-Length: 5\r\n"
+			"\r\n"
+			"0\r\n"
+			"\r\n");
+		string response = readAll(fd, 1024).first;
+		ensure(containsSubstring(response,
+			"HTTP/1.0 400 Bad Request\r\n"
+			"Status: 400 Bad Request\r\n"
+			"Content-Type: text/html; charset=UTF-8\r\n"));
+		ensure(containsSubstring(response,
+			"Connection: close\r\n"
+			"Content-Length: 27\r\n"
+			"cache-control: no-cache, no-store, must-revalidate\r\n"
+			"\r\n"
+			"invalid character in header"));
+	}
 
 	/***** Fixed body handling *****/
 
